@@ -5,7 +5,7 @@ push @ARGV, "";
 if ($ARGV[0] eq "--help")
 {
 print STDERR <<EOT;
-usage:	bdftopsf [[+h] [+u|-u] [+1|-1]]|[-h [+r|-r]]
+usage:	bdftopsf [[+h] [+u|-u] [+1|-1]] | [-h [+r|-r]]
 	[+o|-o NAME] [--] [INPUT [TABLE...]]
 
 +h	PSF mode - write a PSF header. This is the default.
@@ -200,9 +200,9 @@ if ($header != 0)
 		printf OUT "%c%c%c%c", 0x20, 0x00, 0x00, 0x00;
 		printf OUT "%c%c%c%c", $unicode, 0x00, 0x00, 0x00;
 		printf OUT "%c%c%c%c", $chars & 0xFF, $chars >> 8, 0x00, 0x00;
-		printf OUT "%c%c%c%c", $charsize & 0xFF, ($charsize >> 8) & 0xFF, $charsize >> 16, 0x00;
+		printf OUT "%c%c%c%c", $charsize & 0xFF, $charsize >> 8, 0x00, 0x00;
 		printf OUT "%c%c%c%c", $height & 0xFF, $height >> 8, 0x00, 0x00;
-		printf OUT "%c%c%c%c", $width & 0xFF, $width >> 8, 0x00, 0x00;
+		printf OUT "%c%c%c%c", $width, 0x00, 0x00, 0x00;
 	}
 }
 
